@@ -64,26 +64,27 @@ var NAVTREEINDEX =
 "annotated.html",
 "globals_defs_p.html",
 "globals_k.html",
-"group__pw__context.html#gaac1368cbbe2e1a00b066c552c86ba3a8",
-"group__pw__impl__link.html#ga1d14d440f9b78ff302371e49fca32a36",
-"group__pw__link.html#ga72d8e03483fd111c9a9eb87aac3897a2",
-"group__pw__port.html#ga866d33374688faec738124490db2877e",
-"group__pw__session__manager.html#ga9ce6b085d6110a166e03135e3977c7f2",
-"group__spa__ansi.html#ga678d0b293b16e0d6a1fe0acef4915d58",
-"group__spa__device.html#ga9f19955c5b6a77028eb697a130a5f22e",
-"group__spa__log.html#ga05409b56c8a7c7248cc371f5a1e965b6",
-"group__spa__node.html#gad77bdd23db7c222a58280dcda2ed63ff",
-"group__spa__param.html#gad7758d1c91573ef57ebf61ac113bb43e",
-"group__spa__param.html#gga46887990fa9d119f5a5cdae12a985d81a3e57ce2f67cc65627be17e20186b3df5",
-"group__spa__param.html#ggacb274daea0abcce261955323e7d0b1aaab5754c80b7702b8b2283db1f3ec185bf",
-"group__spa__pod.html#ga697129f8c015770ec03468adf9127705",
-"group__spa__thread.html#ga7c5acfdece976cd3f7b12dee4ddb3e41",
-"page_man_pw_jack_1.html",
-"structpw__client__node__events.html#ab1aba9806056fc945c2328f1cc128f6e",
-"structpw__impl__node__events.html#a4364b27231c433313991f473948e5e3f",
-"structpw__session__methods.html#a6720d4c6b23022393bc945c656ba5fe0",
-"structspa__handle__factory.html#aa48d0b857861f618011a9f4a89435484",
-"structspa__pod__bool.html#ace69d7dd77f754dc466e24e0598b865c"
+"group__pw__context.html#ga8970b7ecc709a445142eec2742ac4f3a",
+"group__pw__impl__link.html",
+"group__pw__link.html#ga5d3c859845886244df9d51621460f53b",
+"group__pw__port.html#ga6e316525982a94659dfd8b86d9090c02",
+"group__pw__session__manager.html#ga9c189d1f82467baaf78c4863c8320b3c",
+"group__spa__ansi.html#ga5d126113edfe9df70eb7f68a6f874c85",
+"group__spa__device.html#ga976176b17916248c604ae02498d9f648",
+"group__spa__list.html#gaf76607bd5d48aa7b41d693260a19b68e",
+"group__spa__node.html#gad3d0d597b9c901a69e6b9fd647594c76",
+"group__spa__param.html#gad3d15175ea1dfed4f9d89d6ec0ee86a1",
+"group__spa__param.html#gga46887990fa9d119f5a5cdae12a985d81a28a631aa7be2cf71d49eebb61de0c3fb",
+"group__spa__param.html#ggacb274daea0abcce261955323e7d0b1aaaaede448d2d99717ab6758396d49ebdf3",
+"group__spa__pod.html#ga675878397d60084917d134c5882ea7e2",
+"group__spa__thread.html#ga4f716da417d838544df4e82f4670b79c",
+"page_man_pipewire_pulse_1.html",
+"structpw__client__node__events.html#a3d12bf0a63aba14bc897e4ceb51e4fe4",
+"structpw__impl__node__events.html#a0c45913c502536b96684e02449475a18",
+"structpw__session__info.html#abfebf0a6ad9331c4690ffad37894d660",
+"structspa__handle.html#aaef038ef76a15ddaf5833510535716b4",
+"structspa__pod__array__body.html#a3822d2dc2ac7c37b2a90b91daab8d271",
+"video-play_8c-example.html"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
