@@ -1,5 +1,9 @@
 var NAVTREEINDEX16 =
 {
+"group__spa__thread.html#ga4f716da417d838544df4e82f4670b79c":[10,8,9,8,6],
+"group__spa__thread.html#ga5d2d0635caeef22aaa5a63681255219d":[10,8,9,8,9],
+"group__spa__thread.html#ga6680e7f42845ca460cdaa93abd568e02":[10,8,9,8,5],
+"group__spa__thread.html#ga7454dd6c4ac2967b5c53936dc6ec00b5":[10,8,9,8,7],
 "group__spa__thread.html#ga7c5acfdece976cd3f7b12dee4ddb3e41":[10,8,9,8,10],
 "group__spa__thread.html#ga8dcf8fcd02dbf3c2c49afe37e40b6a43":[10,8,9,8,11],
 "group__spa__thread.html#gaa3418c60a3ab55c44596d0c37ff0fe1b":[10,8,9,8,8],
@@ -245,9 +249,5 @@ var NAVTREEINDEX16 =
 "page_library.html#autotoc_md63":[5,9,6],
 "page_library.html#autotoc_md64":[5,9,7],
 "page_man_pipewire_1.html":[5,12,0],
-"page_man_pipewire_conf_5.html":[5,12,2],
-"page_man_pipewire_pulse_1.html":[5,12,1],
-"page_man_pw_cat_1.html":[5,12,3],
-"page_man_pw_cli_1.html":[5,12,4],
-"page_man_pw_dot_1.html":[5,12,5]
+"page_man_pipewire_conf_5.html":[5,12,2]
 };
