@@ -1,5 +1,22 @@
 var NAVTREEINDEX20 =
 {
+"structpw__session__info.html#abfebf0a6ad9331c4690ffad37894d660":[10,7,4,18,4],
+"structpw__session__methods.html":[10,7,4,11],
+"structpw__session__methods.html#a39a82c063c97d967e5ee82589c390c29":[10,7,4,11,0],
+"structpw__session__methods.html#a66e604601841f9f2252db7c4a4466f6f":[10,7,4,11,4],
+"structpw__session__methods.html#a6720d4c6b23022393bc945c656ba5fe0":[10,7,4,11,2],
+"structpw__session__methods.html#a9311ff4c5e45bce0b1a56ee64e720b09":[10,7,4,11,3],
+"structpw__session__methods.html#afeb231bfac6c5539d258eb06b22e0acf":[10,7,4,11,1],
+"structpw__stream.html":[10,0,5],
+"structpw__stream__control.html":[10,0,2],
+"structpw__stream__control.html#a40b47654929367a6a4f1b83b0b68bfb1":[10,0,2,3],
+"structpw__stream__control.html#a4167f3df47a2d2deff793d3f1f6d31d2":[10,0,2,0],
+"structpw__stream__control.html#a4541b454ba4caaf23f4e772f431294c1":[10,0,2,1],
+"structpw__stream__control.html#a4ffcfbdb7762b0650a28f10eb8c10046":[10,0,2,6],
+"structpw__stream__control.html#a61f6208ade53511ac42e01185f270f62":[10,0,2,2],
+"structpw__stream__control.html#a925311b76a91a9034391da7343865091":[10,0,2,5],
+"structpw__stream__control.html#addabfd3b77bb0cb58bb65b779ab1b3d5":[10,0,2,4],
+"structpw__stream__events.html":[10,0,4],
 "structpw__stream__events.html#a0cdc45fef5f2458a0fd11a6e9ef1f6fb":[10,0,4,7],
 "structpw__stream__events.html#a12fa5918ff2c41cc41d5bf8ae36b3ca3":[10,0,4,3],
 "structpw__stream__events.html#a1de8432b45484bc0e060162b78720c02":[10,0,4,11],
@@ -46,11 +63,13 @@ var NAVTREEINDEX20 =
 "structspa__audio__aec__info.html":[11,0,139],
 "structspa__audio__aec__info.html#a88dbf8b905a3f808af985764cb21fd7c":[11,0,139,0],
 "structspa__audio__aec__methods.html":[11,0,140],
-"structspa__audio__aec__methods.html#a07bacc70c12928c5aa162d88c9146719":[11,0,140,4],
 "structspa__audio__aec__methods.html#a0e357608392e4e4cf8224a523882a80c":[11,0,140,1],
-"structspa__audio__aec__methods.html#a7d3939359e6ad34abf58f74cd0545118":[11,0,140,3],
-"structspa__audio__aec__methods.html#aa16a3e41c4991532b50dc33f3f6001d7":[11,0,140,2],
+"structspa__audio__aec__methods.html#a0ea3331fe5e9ceed6a0969c4f2aaa4c3":[11,0,140,4],
+"structspa__audio__aec__methods.html#a1d1c3a7ec1bd783ddb3cea31bc421cb1":[11,0,140,6],
+"structspa__audio__aec__methods.html#a5b18f9a4430576c06bf7067a61a97854":[11,0,140,5],
+"structspa__audio__aec__methods.html#aadf3db584c3062de5a2af134e6d7014d":[11,0,140,3],
 "structspa__audio__aec__methods.html#af6f30eee3a6af553b3e6ef83f850a691":[11,0,140,0],
+"structspa__audio__aec__methods.html#af7b0dbc68aecaab0c278bc95a9d37503":[11,0,140,2],
 "structspa__audio__info.html":[10,8,7,20],
 "structspa__audio__info.html#a07b9f000b469ff8389b93290a5a06b2b":[10,8,7,20,5],
 "structspa__audio__info.html#a1831d447b0446ff947e879f2de34d410":[10,8,7,20,3],
@@ -230,24 +249,5 @@ var NAVTREEINDEX20 =
 "structspa__graph__state.html#a98a2cfe5aa419430cefaf19e3836ce40":[10,8,5,1,1],
 "structspa__graph__state.html#ade14580f5dc43afc10b857d4233d3f99":[10,8,5,1,0],
 "structspa__handle.html":[10,8,9,5,1],
-"structspa__handle.html#a28e6fe4b4f4bdd29f007a1339cbe972a":[10,8,9,5,1,1],
-"structspa__handle.html#aaef038ef76a15ddaf5833510535716b4":[10,8,9,5,1,2],
-"structspa__handle.html#aaf5d3406480eab83a92db807bc2154c5":[10,8,9,5,1,0],
-"structspa__handle__factory.html":[10,8,9,5,4],
-"structspa__handle__factory.html#a00264d237fb8d45b1878d8ea32fbb5b2":[10,8,9,5,4,4],
-"structspa__handle__factory.html#a528ffc68aa9b406e094c04bba09bbc10":[10,8,9,5,4,0],
-"structspa__handle__factory.html#a6edd8af903eeb185389da41ee945158f":[10,8,9,5,4,1],
-"structspa__handle__factory.html#aa48d0b857861f618011a9f4a89435484":[10,8,9,5,4,2],
-"structspa__handle__factory.html#ad9e9ca49d03aed627c1c1ac5db5266d7":[10,8,9,5,4,3],
-"structspa__hook.html":[10,8,8,4,2],
-"structspa__hook.html#a439678f47d124fd66beec84984c9de75":[10,8,8,4,2,2],
-"structspa__hook.html#a87415e24dddc82ef6048c3572a88cfd7":[10,8,8,4,2,1],
-"structspa__hook.html#aa750440084804e95fb24f95de3eb5d54":[10,8,8,4,2,0],
-"structspa__hook.html#ac503424bd37fd0f8b8e6ba5bb248d8a5":[10,8,8,4,2,3],
-"structspa__hook__list.html":[10,8,8,4,1],
-"structspa__hook__list.html#a6f6f1ee63f0ded77544da4fa3e35a732":[10,8,8,4,1,0],
-"structspa__i18n.html":[10,8,9,2,1],
-"structspa__i18n.html#a4ca10c865fe33ffff4fd9abb9265c0f8":[10,8,9,2,1,0],
-"structspa__i18n__methods.html":[10,8,9,2,2],
-"structspa__i18n__methods.html#a3aa971d572e886ab027a897a288f767b":[10,8,9,2,2,0]
+"structspa__handle.html#a28e6fe4b4f4bdd29f007a1339cbe972a":[10,8,9,5,1,1]
 };
